Sample init scripts and service configuration for bitcoin1776d
==========================================================

Sample scripts and configuration files for systemd, Upstart and OpenRC
can be found in the contrib/init folder.

    contrib/init/bitcoin1776d.service:    systemd service unit configuration
    contrib/init/bitcoin1776d.openrc:     OpenRC compatible SysV style init script
    contrib/init/bitcoin1776d.openrcconf: OpenRC conf.d file
    contrib/init/bitcoin1776d.conf:       Upstart service configuration file
    contrib/init/bitcoin1776d.init:       CentOS compatible SysV style init script

Service User
---------------------------------

All three Linux startup configurations assume the existence of a "bitcoin1776" user
and group.  They must be created before attempting to use these scripts.
The macOS configuration assumes bitcoin1776d will be set up for the current user.

Configuration
---------------------------------

At a bare minimum, bitcoin1776d requires that the rpcpassword setting be set
when running as a daemon.  If the configuration file does not exist or this
setting is not set, bitcoin1776d will shutdown promptly after startup.

This password does not have to be remembered or typed as it is mostly used
as a fixed token that bitcoin1776d and client programs read from the configuration
file, however it is recommended that a strong and secure password be used
as this password is security critical to securing the wallet should the
wallet be enabled.

If bitcoin1776d is run with the "-server" flag (set by default), and no rpcpassword is set,
it will use a special cookie file for authentication. The cookie is generated with random
content when the daemon starts, and deleted when it exits. Read access to this file
controls who can access it through RPC.

By default the cookie is stored in the data directory, but it's location can be overridden
with the option '-rpccookiefile'.

This allows for running bitcoin1776d without having to do any manual configuration.

`conf`, `pid`, and `wallet` accept relative paths which are interpreted as
relative to the data directory. `wallet` *only* supports relative paths.

For an example configuration file that describes the configuration settings,
see `share/examples/bitcoin1776.conf`.

Paths
---------------------------------

### Linux

All three configurations assume several paths that might need to be adjusted.

Binary:              `/usr/bin/bitcoin1776d`  
Configuration file:  `/etc/bitcoin1776/bitcoin1776.conf`  
Data directory:      `/var/lib/bitcoin1776d`  
PID file:            `/var/run/bitcoin1776d/bitcoin1776d.pid` (OpenRC and Upstart) or `/var/lib/bitcoin1776d/bitcoin1776d.pid` (systemd)  
Lock file:           `/var/lock/subsys/bitcoin1776d` (CentOS)  

The configuration file, PID directory (if applicable) and data directory
should all be owned by the bitcoin1776 user and group.  It is advised for security
reasons to make the configuration file and data directory only readable by the
bitcoin1776 user and group.  Access to bitcoin1776-cli and other bitcoin1776d rpc clients
can then be controlled by group membership.

### macOS

Binary:              `/usr/local/bin/bitcoin1776d`  
Configuration file:  `~/Library/Application Support/Bitcoin1776/bitcoin1776.conf`  
Data directory:      `~/Library/Application Support/Bitcoin1776`  
Lock file:           `~/Library/Application Support/Bitcoin1776/.lock`  

Installing Service Configuration
-----------------------------------

### systemd

Installing this .service file consists of just copying it to
/usr/lib/systemd/system directory, followed by the command
`systemctl daemon-reload` in order to update running systemd configuration.

To test, run `systemctl start bitcoin1776d` and to enable for system startup run
`systemctl enable bitcoin1776d`

NOTE: When installing for systemd in Debian/Ubuntu the .service file needs to be copied to the /lib/systemd/system directory instead.

### OpenRC

Rename bitcoin1776d.openrc to bitcoin1776d and drop it in /etc/init.d.  Double
check ownership and permissions and make it executable.  Test it with
`/etc/init.d/bitcoin1776d start` and configure it to run on startup with
`rc-update add bitcoin1776d`

### Upstart (for Debian/Ubuntu based distributions)

Upstart is the default init system for Debian/Ubuntu versions older than 15.04. If you are using version 15.04 or newer and haven't manually configured upstart you should follow the systemd instructions instead.

Drop bitcoin1776d.conf in /etc/init.  Test by running `service bitcoin1776d start`
it will automatically start on reboot.

NOTE: This script is incompatible with CentOS 5 and Amazon Linux 2014 as they
use old versions of Upstart and do not supply the start-stop-daemon utility.

### CentOS

Copy bitcoin1776d.init to /etc/init.d/bitcoin1776d. Test by running `service bitcoin1776d start`.

Using this script, you can adjust the path and flags to the bitcoin1776d program by
setting the BITCOIN1776D and FLAGS environment variables in the file
/etc/sysconfig/bitcoin1776d. You can also use the DAEMONOPTS environment variable here.

### macOS

Copy org.bitcoin1776.bitcoin1776d.plist into ~/Library/LaunchAgents. Load the launch agent by
running `launchctl load ~/Library/LaunchAgents/org.bitcoin1776.bitcoin1776d.plist`.

This Launch Agent will cause bitcoin1776d to start whenever the user logs in.

NOTE: This approach is intended for those wanting to run bitcoin1776d as the current user.
You will need to modify org.bitcoin1776.bitcoin1776d.plist if you intend to use it as a
Launch Daemon with a dedicated bitcoin1776 user.

Auto-respawn
-----------------------------------

Auto respawning is currently only configured for Upstart and systemd.
Reasonable defaults have been chosen but YMMV.
